==> haskell-http-download-0.2.1.0-279-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-KKoxmny4i2RHO6ABVYu19d
key:                  http-download-0.2.1.0-KKoxmny4i2RHO6ABVYu19d
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  a0b05cc3cd5647ffcb1ad61f71ada605
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-KKoxmny4i2RHO6ABVYu19d
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-Fa0BuK0N9mu9JPJP7gaxRT
    bytestring-0.11.5.3 conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    conduit-extra-1.3.8-CgVZWFLveL3JOQpGK40p1j
    crypton-1.0.3-16cGkRi6FF0JFIvaY823Of
    crypton-conduit-0.2.3-3VruN5Co5ezDgsAnxnukIS directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-0.7.19-LiXl0zXhncYKUDAcqgcwk8
    http-conduit-2.3.9.1-Ez7Wwb3oy5J4EzeufIRGd5
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    path-0.9.5-9u1wGR8Auc1A4LZWEoewbj
    path-io-1.8.2-1AdzaiftuUbA5qCx6VC0B0
    retry-0.9.3.1-7RVohaD3s1T6hQjJC83jKU
    rio-0.1.22.0-IUWBs0u6eunDaomdYjfSnj
    rio-prettyprint-0.1.8.0-IFqOjNO8RzXGXwXrgJceqZ

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-download-0.2.1.0-309-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-GIR1i7HxxKm3jMcVqwSikK
key:                  http-download-0.2.1.0-GIR1i7HxxKm3jMcVqwSikK
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  27076b0c41961d3acdfa3e6871655de5
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-GIR1i7HxxKm3jMcVqwSikK
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-G8BjkxE58WI1uqeVjCB0n4
    bytestring-0.11.5.3 conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    conduit-extra-1.3.8-1hrV1nPRDhE45dAx9zvo6P
    crypton-1.0.4-AGWvxb3uQebCjfbnRIxIRG
    crypton-conduit-0.2.3-8YLUbIP3JnnK1gdazlEpS4 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-0.7.19-Iyp8kyAVyHs5ic3dfNFLTs
    http-conduit-2.3.9.1-Jt8i9zz8puP9BUVEul6uLX
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    path-0.9.5-A0ds5dP3EcV42o6nbPLrcF
    path-io-1.8.2-K6qgxe4iNqIfVETezEe3Z
    retry-0.9.3.1-IY64eTdMZLhC7kIJKe8e84
    rio-0.1.22.0-AyTfs4CtSGMI7HNNARqjDz
    rio-prettyprint-0.1.8.0-Hq5kLRBwx7IFnzMz0Ry7ua

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
